@@ -1,11 +1,11 @@
 /* AstroChart.m
  * The circular Astrology chart
  *
- * Copyright (C) 1998-2006 by vhf interservice GmbH
+ * Copyright (C) 1998-2009 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
- * modified: 2006-07-29
+ * modified: 2009-04-01 (radix: no date: draw composite only)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -406,38 +406,40 @@ typedef enum
 }
 
 /* calculate main chart
- * modified: 2006-07-29
+ * modified: 2007-09-03
  */
 - (VGroup*)horoscopeWithCenter:(NSPoint)cp radius:(float)radius
                    tableOrigin:(NSPoint)tableOrigin
                       template:(NSArray*)template color:(NSColor*)color
                          title:(NSString*)title
                            lat:(float)latitude lon:(float)longitude city:(NSString*)city
-                           gmt:(NSCalendarDate*)gmt
-{   NSDictionary	*degreeDict, *nodeDict, *speedLonDict, *decDict, *speedDecDict;
-    NSMutableArray	*planets = [NSMutableArray arrayWithObjects:@"AC", @"MC", nil];
-    NSArray		*nodes = Prefs_Nodes;
-    NSPoint		p0, p1;
-    NSRect		r;
-    NSMutableString	*mString = [NSMutableString string];
-    NSString		*string;
-    VGroup		*group = [VGroup group];
-    VLine		*line;
-    VText		*text;
-    int			i, j, cnt;
-    BOOL		retro = Prefs_ShowRetrograde;
-    float		rotateAC = 0.0;
-    NSFont		*systemFont10 = [NSFont systemFontOfSize:10.0];
-    NSFont		*systemFont12 = [NSFont systemFontOfSize:12.0];
-    NSFont		*systemFont20 = [NSFont systemFontOfSize:20.0];
-    NSFont		*nodeFont   = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE*0.8];
-    NSFont		*planetFont = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE];
-    NSString		*dateFormat = [Prefs_DateFormat stringByAppendingFormat:@" %%H:%%M %%z"];
+                          date:(NSCalendarDate*)date
+{   NSCalendarDate  *utc;
+    NSDictionary    *degreeDict, *nodeDict, *speedLonDict, *decDict, *speedDecDict;
+    NSMutableArray  *planets = [NSMutableArray arrayWithObjects:@"AC", @"MC", nil];
+    NSArray         *nodes = Prefs_Nodes;
+    NSPoint         p0, p1;
+    NSRect          r;
+    NSMutableString *mString = [NSMutableString string];
+    NSString        *string;
+    VGroup          *group = [VGroup group];
+    VLine           *line;
+    VText           *text;
+    int             i, j, cnt;
+    BOOL            retro = Prefs_ShowRetrograde;
+    float           rotateAC = 0.0;
+    NSFont          *systemFont10 = [NSFont systemFontOfSize:10.0];
+    NSFont          *systemFont12 = [NSFont systemFontOfSize:12.0];
+    NSFont          *systemFont20 = [NSFont systemFontOfSize:20.0];
+    NSFont          *nodeFont   = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE*0.8];
+    NSFont          *planetFont = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE];
+    NSString        *dateFormat = [Prefs_DateFormat stringByAppendingFormat:@" %%H:%%M %%z"];
 
+    [(utc = [[date copy] autorelease]) setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
     [planets addObjectsFromArray:Prefs_Objects];
 
     [ephemeris setMeanNodes:Prefs_MeanNodes];
-    degreeDict   = [ephemeris objectDictAtUTC:gmt lat:latitude lon:longitude elev:0.0
+    degreeDict   = [ephemeris objectDictAtUTC:utc lat:latitude lon:longitude elev:0.0
                                   topocentric:Prefs_Topocentric];
     if (Prefs_ACFix)
         rotateAC = 180.0 - [degreeDict floatForKey:@"AC"];	// rotation of chart
@@ -483,7 +485,7 @@ typedef enum
         [group addObject:[self localScaleWithCenter:cp radius:radius*RADIUS_2
                                          scaleSize1:radius*SCALE_MIN*0.5 scaleSize2:radius*SCALE_MAX*0.5
                                         showDegrees:NO rotate:rotateAC
-                                                utc:gmt lat:latitude lon:longitude]];
+                                                utc:utc lat:latitude lon:longitude]];
 
     /* Objects */
     if ( chartTemplate.components & CHART_OBJECTS )
@@ -631,7 +633,7 @@ typedef enum
     /* house cusps */
     if (chartTemplate.components & CHART_HOUSES)
     {   int	houseCnt = 12;
-        double	*house = [ephemeris houseAtUTC:gmt latitude:latitude longitude:longitude houseCount:houseCnt];
+        double	*house = [ephemeris houseAtUTC:utc latitude:latitude longitude:longitude houseCount:houseCnt];
         NSArray	*houseColors = colorWheel(1.0);
 
         for ( i=1; i<=houseCnt; i++ )
@@ -673,9 +675,9 @@ typedef enum
     /* title, date, city, lat, lng
      */
     if (template && (text = [self textWithSubstring:@"#DATE#" fromTemplate:template]))
-    {   NSMutableString	*string = [[[text string] mutableCopy] autorelease];
-        NSRange		range;
-        NSString	*ns, *ew;
+    {   NSMutableString *string = [[[text string] mutableCopy] autorelease];
+        NSRange         range;
+        NSString        *ns, *ew;
 
         range = [string rangeOfString:@"#NAME#"];
         if (range.length)
@@ -683,7 +685,7 @@ typedef enum
         range = [string rangeOfString:@"#DATE#"];
         if (range.length)
             [string replaceCharactersInRange:range
-                                  withString:[gmt descriptionWithCalendarFormat:dateFormat]];
+                                  withString:[date descriptionWithCalendarFormat:dateFormat]];
         range = [string rangeOfString:@"#LOCATION#"];
         if (range.length)
         {
@@ -703,7 +705,7 @@ typedef enum
     }
     else
     {   text = [VText text:[NSString stringWithFormat:@"%@ \n%@ \n%@ %.3f N, %.3f E ", title,
-                          [gmt descriptionWithCalendarFormat:dateFormat], city, latitude, longitude]
+                          [date descriptionWithCalendarFormat:dateFormat], city, latitude, longitude]
                    origin:NSMakePoint(20.0, cp.y - radius*RADIUS_1) color:color angle:0.0
                    center:cp lineHeight:0.0 align:NSLeftTextAlignment font:systemFont12];
         r = [text bounds];
@@ -1032,25 +1034,27 @@ typedef enum
  */
 - (VGroup*)compositeWithCenter:(NSPoint)cp radius:(float)radius
                       template:(NSArray*)template  color:(NSColor*)color title:(NSString*)title
-                  lat:(float)latitude lon:(float)longitude city:(NSString*)city gmt:(NSCalendarDate*)gmt
-{   NSDictionary	*degreeDict;
-    NSArray		*planets = Prefs_Objects;
-    NSPoint		p0, p1;
-    VGroup		*group = [VGroup group];
-    VLine		*line;
-    int			i;
-    float		rotateAC = 0.0;
-    NSColor		*planetColor = [NSColor colorWithDeviceRed:0.0 green:0.0 blue:0.0 alpha:1.0];
-    NSFont		*systemFont10 = [NSFont systemFontOfSize:10.0];
-    NSFont		*systemFont12 = [NSFont systemFontOfSize:12.0];
-    NSFont		*planetFont = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE];
-    NSString		*dateFormat = [Prefs_DateFormat stringByAppendingFormat:@" %%H:%%M %%z"];
+                  lat:(float)latitude lon:(float)longitude city:(NSString*)city date:(NSCalendarDate*)date
+{   NSCalendarDate  *utc;
+    NSDictionary    *degreeDict;
+    NSArray         *planets = Prefs_Objects;
+    NSPoint         p0, p1;
+    VGroup          *group = [VGroup group];
+    VLine           *line;
+    int             i;
+    float           rotateAC = 0.0;
+    NSColor         *planetColor = [NSColor colorWithDeviceRed:0.0 green:0.0 blue:0.0 alpha:1.0];
+    NSFont          *systemFont10 = [NSFont systemFontOfSize:10.0];
+    NSFont          *systemFont12 = [NSFont systemFontOfSize:12.0];
+    NSFont          *planetFont = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE];
+    NSString        *dateFormat = [Prefs_DateFormat stringByAppendingFormat:@" %%H:%%M %%z"];
 
-    degreeDict = [ephemeris objectDictAtUTC:gmt];
+    [(utc = [[date copy] autorelease]) setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
+    degreeDict = [ephemeris objectDictAtUTC:utc];
 
     /* house cusps */
-    {   int	houseCnt = 12;
-        double	*house = [ephemeris houseAtUTC:gmt latitude:latitude longitude:longitude houseCount:houseCnt];
+    {   int     houseCnt = 12;
+        double  *house = [ephemeris houseAtUTC:utc latitude:latitude longitude:longitude houseCount:houseCnt];
 
         if (Prefs_ACFix)
             rotateAC = 180.0 - house[1];	// rotation of chart
@@ -1113,9 +1117,9 @@ typedef enum
         float		viewWidth = [view bounds].size.width;
 
         if (template && (text = [self textWithSubstring:@"#DATE_C#" fromTemplate:template]))
-        {   NSMutableString	*string = [[[text string] mutableCopy] autorelease];
-            NSRange		range;
-            NSString		*ns, *ew;
+        {   NSMutableString *string = [[[text string] mutableCopy] autorelease];
+            NSRange         range;
+            NSString        *ns, *ew;
 
             range = [string rangeOfString:@"#NAME_C#"];
             if (range.length)
@@ -1123,7 +1127,7 @@ typedef enum
             range = [string rangeOfString:@"#DATE_C#"];
             if (range.length)
                 [string replaceCharactersInRange:range
-                                      withString:[gmt descriptionWithCalendarFormat:dateFormat]];
+                                      withString:[date descriptionWithCalendarFormat:dateFormat]];
             range = [string rangeOfString:@"#LOCATION_C#"];
             if (range.length)
             {
@@ -1133,7 +1137,7 @@ typedef enum
                     [string replaceCharactersInRange:range
                                           withString:[NSString stringWithFormat:@"%@ %@ %@ %@ %@",
                                               city, stringFromDeg(Abs(latitude)),  ns,
-                                              stringFromDeg(Abs(longitude)), ew]];
+                                                    stringFromDeg(Abs(longitude)), ew]];
                 else
                     [string replaceCharactersInRange:range
                                           withString:[NSString stringWithFormat:@"%@ %.3f N, %.3f E",
@@ -1143,7 +1147,7 @@ typedef enum
         }
         else
         {   text = [VText text:[NSString stringWithFormat:@"%@ \n%@ \n%@ %.3f N, %.3f E ", title, 
-                              [gmt descriptionWithCalendarFormat:dateFormat], city, latitude, longitude]
+                              [date descriptionWithCalendarFormat:dateFormat], city, latitude, longitude]
                        origin:NSMakePoint(cp.x+viewWidth/2.0-20.0, cp.y - radius*RADIUS_1)
                         color:color angle:0.0 center:cp
                    lineHeight:0.0 align:NSRightTextAlignment font:systemFont12];
@@ -1168,27 +1172,27 @@ typedef enum
 
 /* Tansite aspect table between horoscope and composite
  * created:  2005-07-03
- * modified: 2005-09-19 (show symbol row on the left for symmetry)
+ * modified: 2009-04-01 (no gmtH -> don't draw this stuff)
  * Author:  Ilonka Fleischmann
  */
 - (VGroup*)compositeTable:(NSPoint)cp tableOrigin:(NSPoint)tableOrigin
                      latH:(float)latitudeH lonH:(float)longitudeH gmtH:(NSCalendarDate*)gmtH
                      latC:(float)latitudeC lonC:(float)longitudeC gmtC:(NSCalendarDate*)gmtC
-{   NSDictionary	*degreeDictH, *degreeDictC, *speedLonDict;
-    NSMutableArray	*planets  = [NSMutableArray arrayWithObjects:@"AC", @"MC", nil];
-    NSMutableArray	*planetsH = [NSMutableArray array];
-    NSMutableArray	*planetsC = [NSMutableArray array];
-    //NSPoint		tableOrigin = NSMakePoint(312.0, 37.0);
-    NSMutableString	*mString = [NSMutableString string];
-    NSString		*string;
-    NSColor		*color = [NSColor blackColor];
-    NSPoint		p0, p1;
-    NSRect		r;
-    VLine		*line;
-    VText		*text;
-    int			i, j, cnt;
-    BOOL		showCombiAspects = NO;	// YES = show inner/outer + outer/inner
-    BOOL		show2ndSymbolRow = NO;	// YES displays 2nd row of symbols to the right of degrees
+{   NSDictionary    *degreeDictH = nil, *degreeDictC, *speedLonDict;
+    NSMutableArray  *planets  = [NSMutableArray arrayWithObjects:@"AC", @"MC", nil];
+    NSMutableArray  *planetsH = [NSMutableArray array];
+    NSMutableArray  *planetsC = [NSMutableArray array];
+    //NSPoint       tableOrigin = NSMakePoint(312.0, 37.0);
+    NSMutableString *mString = [NSMutableString string];
+    NSString        *string;
+    NSColor         *color = [NSColor blackColor];
+    NSPoint         p0, p1;
+    NSRect          r;
+    VLine           *line;
+    VText           *text;
+    int             i, j, cnt;
+    BOOL            showCombiAspects = NO;	// YES = show inner/outer + outer/inner
+    BOOL            show2ndSymbolRow = NO;	// YES displays 2nd row of symbols to the right of degrees
 
     speedLonDict = [ephemeris currentSpeedLonDict];
 
@@ -1196,7 +1200,8 @@ typedef enum
     [planetsH addObjectsFromArray:Prefs_Objects];	// Planets 1 (outside)
     [planetsC addObjectsFromArray:Prefs_Objects];	// Planets 2 (inside)
 
-    degreeDictH = [ephemeris objectDictAtUTC:gmtH lat:latitudeH lon:longitudeH elev:0.0 topocentric:Prefs_Topocentric];
+    if (gmtH)
+        degreeDictH = [ephemeris objectDictAtUTC:gmtH lat:latitudeH lon:longitudeH elev:0.0 topocentric:Prefs_Topocentric];
     degreeDictC = [ephemeris objectDictAtUTC:gmtC lat:latitudeC lon:longitudeC elev:0.0 topocentric:Prefs_Topocentric];
 
     /*
@@ -1341,7 +1346,7 @@ typedef enum
             [subGroup addObject:line];
         }
 
-        if ( showCombiAspects )
+        if ( showCombiAspects && gmtH )
         {
             /* diagonal seperating lines */
             for (i=1; i<=(int)[planetsC count]; i++ )	// vertical-direction
@@ -1759,24 +1764,27 @@ typedef enum
 }
 
 /* main calculation method
- * modified: 2006-07-29
+ * modified: 2009-04-01 (date = nil -> still draw composite)
  */
-- (void)radix:(NSCalendarDate*)gmt
+- (void)radix:(NSCalendarDate*)date
     longitude:(float)longitude latitude:(float)latitude
          city:(NSString*)city
         title:(NSString*)title composite:(NSDictionary*)composite
-{   NSArray			*layerList = [view layerList];
-    LayerObject			*layer;
-    VGraphic			*g;
-    NSPoint			cp, tableOrigin, tableOriginC;
-    float			radius, radiusC, rotateAC = 0.0;
-    int				ixMaskRadix = -1, ixRadix = 0, ixTemplate, i;
-    NSArray			*template = nil;	// list of marks and text showing positions
-    NSMutableDictionary		*infoDict = nil;
-    NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
+{   NSCalendarDate          *utc = nil;
+    NSArray                 *layerList = [view layerList];
+    LayerObject             *layer;
+    VGraphic                *g;
+    NSPoint                 cp, tableOrigin, tableOriginC;
+    float                   radius, radiusC, rotateAC = 0.0;
+    int                     ixMaskRadix = -1, ixRadix = 0, ixTemplate, i;
+    NSArray                 *template = nil;	// list of marks and text showing positions
+    NSMutableDictionary     *infoDict = nil;
+    NSNotificationCenter    *notificationCenter = [NSNotificationCenter defaultCenter];
 
-    if (!gmt || ![[[view window] title] hasPrefix:CHART_PREFIX])
+    if ( ![[[view window] title] hasPrefix:CHART_PREFIX] )
         return;
+    if (date)
+        [(utc = [[date copy] autorelease]) setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
 
     ephemeris = [Astro_Principal ephemeris];
 
@@ -1848,67 +1856,69 @@ typedef enum
 
     /* chart
      */
-    layer = [layerList objectAtIndex:ixRadix];
-    [layer removeAllObjects];
-    if (Prefs_ACFix)
-        rotateAC = 180.0 - ac(sideralTime(gmt, longitude), latitude);
+    if ( date )
+    {
+        layer = [layerList objectAtIndex:ixRadix];
+        [layer removeAllObjects];
+        if (Prefs_ACFix)
+            rotateAC = 180.0 - ac(sideralTime(utc, longitude), latitude);
 
-    /* no mask -> calculate basics
-     */
-    {   //maskLayer = (ixMaskRadix) ? [layerList objectAtIndex:ixMaskRadix] : layer;
+        /* no mask -> calculate basics
+            */
+        {   //maskLayer = (ixMaskRadix) ? [layerList objectAtIndex:ixMaskRadix] : layer;
 
-        /* center star */
-        if (ixMaskRadix < 0 && chartTemplate.components & CHART_CENTER)
-            [layer addObject:[self starWithCenter:cp radius:radius*STAR_SIZE rotate:rotateAC]];
+            /* center star */
+            if (ixMaskRadix < 0 && chartTemplate.components & CHART_CENTER)
+                [layer addObject:[self starWithCenter:cp radius:radius*STAR_SIZE rotate:rotateAC]];
 
-        /* Ecliptic circle: global houses and signs */
-        if ( (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
-             && chartTemplate.components & CHART_ZODIAC )
-            [layer addObject:[self eclipticWithCenter:cp
-                                              radius1:chartTemplate.radiusMax radius2:radius
-                                           symbolSize:radius*SYMBOL_SIZE rotate:rotateAC]];
+            /* Ecliptic circle: global houses and signs */
+            if ( (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
+                 && chartTemplate.components & CHART_ZODIAC )
+                [layer addObject:[self eclipticWithCenter:cp
+                                                  radius1:chartTemplate.radiusMax radius2:radius
+                                               symbolSize:radius*SYMBOL_SIZE rotate:rotateAC]];
 
-        /* scale */
-        if ( (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
-             && chartTemplate.components & CHART_SCALE )
-            [layer addObject:[self scaleWithCenter:cp radius:radius
-                                        scaleSize1:radius*SCALE_MIN scaleSize2:radius*SCALE_MAX
-                                        degreeType:SCALEDEG_360 rotate:rotateAC]];
-    }
-    /* rotate AC to the left
-     * we create a rotated copy of the mask and turn off the mask
-     */
-    if (ixMaskRadix >= 0 && rotateAC)	// rotate Mask
-    {   NSArray	*list = [[layerList objectAtIndex:ixMaskRadix] list];
-
-        [[layerList objectAtIndex:ixMaskRadix] setState:0];
-        for (i=0; i<(int)[list count]; i++)
-        {   VGraphic	*g = [[[list objectAtIndex:i] copy] autorelease];
-
-            if (![[list objectAtIndex:i] isLocked])	// check original, for copy loses the lock !
-            {   [g setAngle:-rotateAC withCenter:cp];
-                if ([g isKindOfClass:[VText class]] && [(VText*)g isSerialNumber])
-                    [g rotate:[g rotAngle]];
-            }
-            [layer addObject:g];
+            /* scale */
+            if ( (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
+                 && chartTemplate.components & CHART_SCALE )
+                [layer addObject:[self scaleWithCenter:cp radius:radius
+                                            scaleSize1:radius*SCALE_MIN scaleSize2:radius*SCALE_MAX
+                                            degreeType:SCALEDEG_360 rotate:rotateAC]];
         }
-    }
-    else if (ixMaskRadix >= 0)		// no rotation -> enable mask
-        [[layerList objectAtIndex:ixMaskRadix] setState:1];
+        /* rotate AC to the left
+            * we create a rotated copy of the mask and turn off the mask
+            */
+        if (ixMaskRadix >= 0 && rotateAC)	// rotate Mask
+        {   NSArray	*list = [[layerList objectAtIndex:ixMaskRadix] list];
 
-    g = [self horoscopeWithCenter:cp radius:radius tableOrigin:tableOrigin
-                         template:template color:[NSColor blackColor]
-                            title:title lat:latitude lon:longitude city:city gmt:gmt];
-    [layer addObjectsFromArray:[(VGroup*)g list]];
+            [[layerList objectAtIndex:ixMaskRadix] setState:0];
+            for (i=0; i<(int)[list count]; i++)
+            {   VGraphic	*g = [[[list objectAtIndex:i] copy] autorelease];
 
-    /* give other modules a chance to add their stuff
-     */
-    infoDict = [NSMutableDictionary dictionaryWithObjectsAndKeys:
+                if (![[list objectAtIndex:i] isLocked])	// check original, for copy loses the lock !
+                {   [g setAngle:-rotateAC withCenter:cp];
+                    if ([g isKindOfClass:[VText class]] && [(VText*)g isSerialNumber])
+                        [g rotate:[g rotAngle]];
+                }
+                [layer addObject:g];
+            }
+        }
+        else if (ixMaskRadix >= 0)		// no rotation -> enable mask
+            [[layerList objectAtIndex:ixMaskRadix] setState:1];
+
+        g = [self horoscopeWithCenter:cp radius:radius tableOrigin:tableOrigin
+                             template:template color:[NSColor blackColor]
+                                title:title lat:latitude lon:longitude city:city date:date];
+        [layer addObjectsFromArray:[(VGroup*)g list]];
+
+        /* give other modules a chance to add their stuff
+         */
+        infoDict = [NSMutableDictionary dictionaryWithObjectsAndKeys:
                     layerList,                                  @"layerList",
                     layer,                                      @"layerChart",
                     [NSNumber numberWithFloat:rotateAC],        @"rotateAC",
                     title,                                      @"title",
-                    gmt,                                        @"date",
+                    utc,                                        @"date",
                     [NSNumber numberWithFloat:latitude],        @"lat",
                     [NSNumber numberWithFloat:longitude],       @"lon",
                     propertyListFromNSPoint(cp),                @"center",
@@ -1916,89 +1926,95 @@ typedef enum
                     [NSNumber numberWithFloat:radius*RADIUS_3], @"radiusComposite",
                     [NSNumber numberWithFloat:radius*RADIUS_4], @"radiusCenter",
                     composite,                                  @"composite", nil];
-    [notificationCenter postNotificationName:AstroAddChartParts
-                                      object:self userInfo:infoDict];
+        [notificationCenter postNotificationName:AstroAddChartParts
+                                          object:self userInfo:infoDict];
 
-    /* Create Interval Chart
-     */
-    if ( DiffPoint(chartTemplate.centerI[0], NSZeroPoint) > 0.0 )
-    {   int		i;
-        int		min = Prefs_AstroInterval, minMinutes = 999999;
-        NSString	*strFormat;
-        VText		*text;
+        /* Create Interval Chart
+         */
+        if ( DiffPoint(chartTemplate.centerI[0], NSZeroPoint) > 0.0 )
+        {   int		i;
+            int		min = Prefs_AstroInterval, minMinutes = 999999;
+            NSString	*strFormat;
+            VText		*text;
 
-        /* find min interval = base interval */
-        if (min != 0)
-        {
-            for (i=0; DiffPoint(chartTemplate.centerI[i], NSZeroPoint) > 0.0; i++)
+            /* find min interval = base interval */
+            if (min != 0)
             {
+                for (i=0; DiffPoint(chartTemplate.centerI[i], NSZeroPoint) > 0.0; i++)
+                {
+                    strFormat = [NSString stringWithFormat:@"#TIME_%d", i+1];
+                    if ( (text = [self textWithSubstring:strFormat fromTemplate:template]) )
+                    {   int	minutes;
+
+                        minutes = [[[text string] substringFromIndex:[strFormat length]] intValue];
+                        if (minutes != 0 && Abs(minutes) < minMinutes)
+                            minMinutes = Abs(minutes);
+                    }
+                }
+            }
+
+            for (i=0; DiffPoint(chartTemplate.centerI[i], NSZeroPoint) > 0.0; i++)
+            {   NSCalendarDate  *dateI = utc;   // FIXME: do interval charts want a time zone ?
+                NSPoint         cp;
+                float           rad;
+
+                cp  = chartTemplate.centerI[i];
+                rad = chartTemplate.radiusI[i];
+
                 strFormat = [NSString stringWithFormat:@"#TIME_%d", i+1];
                 if ( (text = [self textWithSubstring:strFormat fromTemplate:template]) )
                 {   int	minutes;
 
                     minutes = [[[text string] substringFromIndex:[strFormat length]] intValue];
-                    if (minutes != 0 && Abs(minutes) < minMinutes)
-                        minMinutes = Abs(minutes);
+                    if (min != 0 && minutes != 0)	// override interval from prefs
+                    {   float f = (minutes) ? Max((Abs(minutes)/minMinutes), 1.0) : 1.0;
+                        minutes = f * ((minutes>0) ? min : -min);
+                    }
+                    dateI = [utc dateByAddingYears:0 months:0 days:0 hours:0 minutes:minutes seconds:0];
+                    [text replaceTextWithString:[dateI descriptionWithCalendarFormat:@"%H:%M"]];
+                    [layer addObject:text];
                 }
+
+                if ( min > 10 )	// delta > 10 minutes -> calculate objects
+                    [ephemeris objectDictAtUTC:dateI lat:latitude lon:longitude elev:0.0
+                                   topocentric:Prefs_Topocentric];
+                [infoDict setObject:dateI                          forKey:@"date"];
+                [infoDict setObject:propertyListFromNSPoint(cp)    forKey:@"center"];
+                [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radius"];
+                [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radiusComposite"];
+                [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radiusCenter"];
+                [infoDict setObject:@"1"                           forKey:@"isIntervalChart"];
+                [notificationCenter postNotificationName:AstroAddChartParts
+                                                  object:self userInfo:infoDict];
             }
         }
-
-        for (i=0; DiffPoint(chartTemplate.centerI[i], NSZeroPoint) > 0.0; i++)
-        {   NSCalendarDate	*dateI = gmt;
-            NSPoint		cp;
-            float		rad;
-
-            cp  = chartTemplate.centerI[i];
-            rad = chartTemplate.radiusI[i];
-
-            strFormat = [NSString stringWithFormat:@"#TIME_%d", i+1];
-            if ( (text = [self textWithSubstring:strFormat fromTemplate:template]) )
-            {   int	minutes;
-
-                minutes = [[[text string] substringFromIndex:[strFormat length]] intValue];
-                if (min != 0 && minutes != 0)	// override interval from prefs
-                {   float f = (minutes) ? Max((Abs(minutes)/minMinutes), 1.0) : 1.0;
-                    minutes = f * ((minutes>0) ? min : -min);
-                }
-                dateI = [gmt dateByAddingYears:0 months:0 days:0 hours:0 minutes:minutes seconds:0];
-                [text replaceTextWithString:[dateI descriptionWithCalendarFormat:@"%H:%M"]];
-                [layer addObject:text];
-            }
-
-            if ( min > 10 )	// delta > 10 minutes -> calculate objects
-                [ephemeris objectDictAtUTC:dateI lat:latitude lon:longitude elev:0.0
-                               topocentric:Prefs_Topocentric];
-            [infoDict setObject:dateI                          forKey:@"date"];
-            [infoDict setObject:propertyListFromNSPoint(cp)    forKey:@"center"];
-            [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radius"];
-            [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radiusComposite"];
-            [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radiusCenter"];
-            [infoDict setObject:@"1"                           forKey:@"isIntervalChart"];
-            [notificationCenter postNotificationName:AstroAddChartParts
-                                              object:self userInfo:infoDict];
-        }
     }
 
     /* composite */
     if ( [composite intForKey:@"doCalculate"] && ixComposite >= 0)
-    {   NSCalendarDate	*gmtH = gmt;	// save date of outside chart for composite table
+    {   //NSCalendarDate	*date, *utc;    // local for composite
+        NSCalendarDate  *utcH = utc;    // pointer for creating the table
 
         layer = [layerList objectAtIndex:ixComposite];
         [layer removeAllObjects];
 
-        gmt = [composite objectForKey:@"date"];
-        if ([gmt isKindOfClass:[NSString class]])
-            gmt = [NSCalendarDate dateWithString:[composite stringForKey:@"date"]
-                                  calendarFormat:@"%Y-%m-%d %H:%M %Z"];
-        if (!gmt)
-            gmt = [NSCalendarDate date];
-        [gmt setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
+        date = [composite objectForKey:@"date"];
+        if ([date isKindOfClass:[NSString class]])   // date passed as a string (deprecated!)
+        {   date = [NSCalendarDate dateWithString:[composite stringForKey:@"date"]
+                                   calendarFormat:@"%Y-%m-%d %H:%M %Z"];
+            NSLog(@"radix:...: composite date given to us as a string! Deprecated! '%@'", date);
+        }
+        if (!date)
+            date = [NSCalendarDate date];
+        utc = [[date copy] autorelease];
+        [utc setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
         if (Prefs_ACFix)
-            rotateAC = 180.0 - ac(sideralTime(gmt, [composite floatForKey:@"lon"]), [composite floatForKey:@"lat"]);
+            rotateAC = 180.0 - ac(sideralTime(utc, [composite floatForKey:@"lon"]),
+                                                   [composite floatForKey:@"lat"]);
 
-        {   NSMutableArray	*list;
-            VPath		*path;
-            VArc		*arc;
+        {   NSMutableArray  *list;
+            VPath           *path;
+            VArc            *arc;
 
             /* filled ring */
             if ( ixMaskComposite < 0 && chartTemplate.components & CHART_ZODIAC )
@@ -2061,13 +2077,13 @@ typedef enum
         g = [self compositeWithCenter:cp radius:radius template:template color:[NSColor blackColor]
                                 title:[composite stringForKey:@"name"]
                                   lat:[composite floatForKey:@"lat"] lon:[composite floatForKey:@"lon"]
-                                 city:[composite stringForKey:@"city"] gmt:gmt];
+                                 city:[composite stringForKey:@"city"] date:date];
         [layer addObject:g];
 
         /* add composite table */
         g = [self compositeTable:cp tableOrigin:(NSPoint)tableOriginC
-                            latH:latitude                       lonH:longitude                      gmtH:gmtH
-                            latC:[composite floatForKey:@"lat"] lonC:[composite floatForKey:@"lon"] gmtC:gmt];
+                            latH:latitude                       lonH:longitude                      gmtH:utcH
+                            latC:[composite floatForKey:@"lat"] lonC:[composite floatForKey:@"lon"] gmtC:utc];
         [layer addObject:g];
 
         [layer setState:1];	// make composite layer visible
