@@ -1,10 +1,10 @@
 /* AstroPanel.h
  *
- * Copyright (C) 1999-2006 by vhf interservice GmbH
+ * Copyright (C) 1999-2008 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  1995-08-10
- * Modified: 2006-01-08
+ * Modified: 2008-03-17
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -30,16 +30,16 @@
 
 #include "APBasicLevel.h"
 
-#define AP_CHART	0
-#define AP_MAP		1
-#define AP_SEARCH	2
-#define AP_FLOWCHART	3
-#define AP_DEFAULT	99
+#define AP_CHART        0
+#define AP_MAP          1
+#define AP_SEARCH       2
+#define AP_FLOWCHART    3
+#define AP_DEFAULT      99
 
-#define BUTTONLEFT	0
-#define BUTTONRIGHT	1
-#define BUTTONUP	2
-#define BUTTONDOWN	3
+#define BUTTONLEFT      0
+#define BUTTONRIGHT     1
+#define BUTTONUP        2
+#define BUTTONDOWN      3
 
 #if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)
     #define USE_TABVIEW 0
@@ -52,12 +52,12 @@
 
 @interface AstroPanel:APBasicLevel
 {
-    id			levelRadio;
+    id              levelRadio;
 #if USE_TABVIEW
-    NSTabView		*tabView;
-    BOOL		setSubLevel;
+    NSTabView       *tabView;
+    BOOL            setSubLevel;
 #else
-    NSScrollView	*levView;
+    NSScrollView    *levView;
 #endif
 
     int			levelCnt;
@@ -71,7 +71,7 @@
     BOOL		tabEvent;
 }
 
-- init;
+- awakeFromNib;
 - (void)update:sender;
 - (void)setLevelAt:(int)level;
 
