@@ -1,11 +1,11 @@
 /*
  * AstroPanel.m
  *
- * Copyright 1999-2006 by vhf interservice GmbH
+ * Copyright 1999-2008 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  1995-08-10
- * Modified: 2006-02-01
+ * Modified: 2008-07-23 (awakeFromNib instead of init)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -41,11 +41,16 @@
 #if USE_TABVIEW	// GNUstep, MAC-OS X
 - (BOOL)canBecomeKeyWindow	{ return YES; }
 
-- init
-{   NSTabViewItem		*item;
-    NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
+- awakeFromNib
+{   static BOOL             awake = NO;
+    NSTabViewItem           *item;
+    NSNotificationCenter    *notificationCenter = [NSNotificationCenter defaultCenter];
+
+    if ( awake )    // we are already awake
+        return self;
+    awake = YES;
+    //[super init];
 
-    [super init];
     [tabView setDelegate:self];
     levelCnt = 0;
 
@@ -108,8 +113,8 @@
 /* set view of tabView (sub tabs)
  */
 - (void)setLevelAt:(int)level
-{   NSTabViewItem	*item;
-    NSView		*newView = [[self windowAt:level] contentView];
+{   NSTabViewItem   *item;
+    NSView          *newView = [[self windowAt:level] contentView];
 
     [activeWindow displayWillEnd];
     setSubLevel = YES;
@@ -132,10 +137,14 @@
 
 #else	// OpenStep
 
-- init
-{   NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
+- awakeFromNib
+{   static BOOL             awake = NO;
+    NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
 
-    [super init];
+    if ( awake )    // we are already awake
+        return self;
+    awake = YES;
+    //[super init];
 
     /* add observer to add tabs */
     [notificationCenter addObserver:self
@@ -170,7 +179,7 @@
     }
     else
     {
-        [self setLevelView:NULL];
+        [self setLevelView:nil];
         activeWindow = self;
         return;
     }
@@ -299,8 +308,8 @@
  */
 
 - (void)addTabNotification:(NSNotification*)notification
-{   APBasicLevel	*panel = [notification object];
-    int			level = levelCnt;
+{   APBasicLevel    *panel = [notification object];
+    int             level = levelCnt;
 
     windows[level] = [panel retain];
     levelCnt ++;
@@ -309,7 +318,7 @@
     [[panel contentView] retain];	// GNUstep
 
 #if USE_TABVIEW	// GNUstep, MAC-OS X
-    {   NSTabViewItem	*item;
+    {   NSTabViewItem   *item;
 
         item = [[NSTabViewItem alloc] initWithIdentifier:[panel name]];
         [item setLabel:[panel name]];
@@ -317,8 +326,8 @@
         [tabView addTabViewItem:item];
     }
 #else
-    {   UITabActionCell	*item;
-        NSSize		size;
+    {   UITabActionCell *item;
+        NSSize          size;
 
         [levelRadio addColumn];
         item = [levelRadio cellAtRow:0 column:level];
