@@ -89,8 +89,8 @@
     return instance;
 }
 
-/*  137.1234 ->  137 7'24"
- * -137.1234 -> -137 7'24"
+/*  137.1234 ->  137  7'24"
+ * -137.1234 -> -137  7'24"
  */
 NSString *stringFromDeg(float deg)
 {
@@ -180,6 +180,9 @@ NSString *stringFromDeg(float deg)
                              object:nil];
 
     /* add a menu item for the AstroPanel */
+//#ifdef __APPLE__
+//    [toolMenu addItem:[NSMenuItem separatorItem]];
+//#endif
     [toolMenu addItemWithTitle:@"Astro Panel ..."
                         action:@selector(showAstroPanel:)
                  keyEquivalent:@""];
@@ -217,7 +220,7 @@ NSString *stringFromDeg(float deg)
                 externalNameTable:[NSDictionary dictionaryWithObject:self forKey:@"NSOwner"]
                          withZone:[self zone]] )
             NSLog(@"Cannot load AstroPanel interface file");
-        [astroPanel init];
+        [astroPanel awakeFromNib];  // FIXME: GNustep doesn't call this on it's own
     }
     [astroPanel setFrameUsingName:@"AstroPanel"];
     [astroPanel setFrameAutosaveName:@"AstroPanel"];
@@ -326,7 +329,7 @@ NSString *stringFromDeg(float deg)
         NSLog(@"AstroPrincipal, notification send from object %@, shoult be DocView!", view);
 }
 
-/* notification that we have to calculate a chart
+/* notification that we have to calculate a chart (CalculateChartNotification)
  *
  * dict   name	    NSString       title of the chart
  *        date      NSCalendarDate date of the chart
@@ -334,14 +337,16 @@ NSString *stringFromDeg(float deg)
  *        lon       NSNumber       longitude
  *        city      NSString       location
  *        composite NSDictionary   optional dictionary with entries like above for a composite chart
+ *
+ * modified: 2009-04-01 (no data for main chart but composite -> we set composite only)
  */
 - (void)calculateChart:(NSNotification*)notification
 {   NSDictionary	*dict = [notification object];
 
     if ([dict isKindOfClass:[NSDictionary class]])
-    {   int		i;
-        Document	*doc;
-        AstroChart	*astroChart;
+    {   int         i;
+        Document    *doc;
+        AstroChart  *astroChart;
 
         for ( i=[[NSApp windows] count]-1; i>=0; i-- )
         {   doc = [(App*)NSApp documentInWindow:[[(App*)NSApp windows] objectAtIndex:i]];
@@ -353,15 +358,37 @@ NSString *stringFromDeg(float deg)
             return;
         }
 
-  	astroChart = [[astroPanel windowAt:AP_CHART] astroChart];
+        astroChart = [[astroPanel windowAt:AP_CHART] astroChart];
         if (!astroChart)
             astroChart = [AstroChart astroChartWithView:[doc documentView]];
-        [astroChart radix:[dict objectForKey:@"date"]
-                longitude:[dict floatForKey:@"lon"]
-                 latitude:[dict floatForKey:@"lat"]
-                     city:[dict objectForKey:@"city"]
-                    title:[dict objectForKey:@"name"]
-                composite:[dict objectForKey:@"composite"]];
+#if 0
+        /* only composite -> use data from astro panel */
+        if ( ![dict objectForKey:@"date"] &&
+             [dict objectForKey:@"composite"] && [[dict objectForKey:@"composite"] objectForKey:@"date"] )
+        {   //NSDictionary    data = [[astroPanel windowAt:AP_CHART] data];
+
+            //[data setObject:[dict objectForKey:@"composite"] forKey:@"composite"];
+            //dict = data;
+            dict = [[dict objectForKey:@"composite"] mutableCopy];
+            [(NSMutableDictionary*)dict
+                    setObject:[[dict objectForKey:@"date"] descriptionWithCalendarFormat:@"%Y-%m-%d %H:%M %z"]
+                    forKey:@"date"];   // workaround: we have to fix [APChart setCompositeEvent]
+            // this puts the data to the right side of the astro-panel (inside) and will redraw outside + inside
+            // what we want is to draw only the inside with the method below: no date -> draw inside only
+            [[NSNotificationCenter defaultCenter] postNotificationName:AstroUpdateEvent
+                                                                object:dict
+                                                              userInfo:[NSDictionary dictionaryWithObject:@"1" forKey:@"composite"]];
+        }
+        //else
+#endif
+        {
+            [astroChart radix:[dict objectForKey:@"date"]
+                    longitude:[dict floatForKey:@"lon"]
+                     latitude:[dict floatForKey:@"lat"]
+                         city:[dict objectForKey:@"city"]
+                        title:[dict objectForKey:@"name"]
+                    composite:[dict objectForKey:@"composite"]];
+        }
     }
     else
         NSLog(@"AstroPrincipal (calculateChart), notification send with an object not a dictionary!");
