@@ -125,7 +125,7 @@
     sec = ((24.0*(jd+0.5-jd0) - hour) - min*60.0)/3600.0;
 
     date = [NSCalendarDate dateWithYear:year month:month day:day hour:hour minute:min second:sec
-                               timeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
+                               timeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
     return date;
 }
 
