@@ -1,11 +1,11 @@
 /* DocViewMap.m
  * Map additions for DocView.m
  *
- * Copyright (C) 2001-2006 by vhf interservice GmbH
+ * Copyright (C) 2001-2007 by vhf interservice GmbH
  * Author:   Ilonka Fleischmann
  *
  * created:  2001-08-??
- * modified: 2003-07-19
+ * modified: 2007-09-03
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -169,16 +169,16 @@ printf("%s  p = {%f %f} -> lon = %f, lat = %f\n", [[date description] cString],
 
 /* create tables of planets relating chart
  * positions, angles, mirrors, harmonies
- * modified: 2006-02-19
+ * modified: 2007-09-03
  */
 - (void)createMapWithCenter:(NSPoint)center size:(NSSize)size grid:(float)gridSize
                    features:(NSDictionary*)features
-{   int			i, l;
-    LayerObject		*layer = nil;
-    NSMutableDictionary	*dict;
-    NSAutoreleasePool	*pool = [NSAutoreleasePool new];
-    NSArray		*allKeys;
-    Map			*map = [statusDict objectForKey:@"map"];
+{   int                 i, l;
+    LayerObject         *layer = nil;
+    NSMutableDictionary *dict;
+    NSAutoreleasePool   *pool = [NSAutoreleasePool new];
+    NSArray             *allKeys;
+    Map                 *map = [statusDict objectForKey:@"map"];
 
     /* if we are not a map view, we find one and pass the job over or return */
     if ( ![self isMap] )
@@ -231,9 +231,11 @@ printf("%s  p = {%f %f} -> lon = %f, lat = %f\n", [[date description] cString],
 
     /* map AC/MC (Axes) lines on planets, FIXME: map aspects to AC/MC */
     if ([features objectForKey:@"featureACMC"])
-    {   NSCalendarDate	*utc = [(APChart*)[[Astro_Principal astroPanel] windowAt:AP_CHART] date];
-        VGroup		*group;
+    {   APChart         *chartPanel = [[Astro_Principal astroPanel] windowAt:AP_CHART];
+        NSCalendarDate  *utc = [chartPanel date];
+        VGroup          *group;
 
+        [utc setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
         if ( (group = [map mapChartWithDate:utc title:nil inBounds:[self bounds]]) )
         {
             //layer = [layerList objectAtIndex:[layerList count]-1];
@@ -244,11 +246,12 @@ printf("%s  p = {%f %f} -> lon = %f, lat = %f\n", [[date description] cString],
 
     /* map house tips (keep house tip on Zodiac degree for every location) */
     if ([features objectForKey:@"featureHouses"])
-    {   APChart		*chartPanel = [[Astro_Principal astroPanel] windowAt:AP_CHART];
-        NSCalendarDate	*utc = [chartPanel date];
-        float		lat = [chartPanel latitude], lon = [chartPanel longitude];
-        VGroup		*group;
+    {   APChart         *chartPanel = [[Astro_Principal astroPanel] windowAt:AP_CHART];
+        NSCalendarDate  *utc = [chartPanel date];
+        float           lat = [chartPanel latitude], lon = [chartPanel longitude];
+        VGroup          *group;
 
+        [utc setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
         if ( (group = [map mapHousesAtDate:utc lat:lat lon:lon title:nil inBounds:[self bounds]]) )
         {
             //layer = [layerList objectAtIndex:[layerList count]-1];
