@@ -1,11 +1,12 @@
 /* EventManager.m
  * controller class and files owner of the EventPanel
  *
- * Copyright (C) 2003-2006 by vhf interservice GmbH
+ * Copyright (C) 2003-2009 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-06-22
- * modified: 2006-01-15 (date formats)
+ * modified: 2009-02-28 (-add, -modify, -remove: test for nil events)
+ *           2006-01-15 (date formats)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -213,7 +214,7 @@ static int indexFromType(NSString *typeString)
 }
 
 /* add new entry
- * modified: 2006-01-15
+ * modified: 2009-02-28
  */
 - (void)add:sender
 {   NSMutableDictionary	*event = [NSMutableDictionary dictionary];
@@ -227,6 +228,8 @@ static int indexFromType(NSString *typeString)
     if (folderIx < 0)
         return;
     events = [eventDict objectForKey:[folders objectAtIndex:folderIx]];
+    if (!events)
+        return;
 
     /* make events list and entries mutable */
     if (![events isKindOfClass:[NSMutableArray class]])
@@ -328,9 +331,11 @@ static int indexFromType(NSString *typeString)
     if (eventIx < 0)
         return;
     events = [eventDict objectForKey:[folders objectAtIndex:folderIx]];
+    if (!events)
+        return;
 
     /* make event list and entries mutable */
-    if (![events isKindOfClass:[NSMutableArray class]])
+    if ( ![events isKindOfClass:[NSMutableArray class]] )
     {
         events = [[events mutableCopy] autorelease];
         [eventDict setObject:events forKey:[folders objectAtIndex:folderIx]];
@@ -406,14 +411,16 @@ static int indexFromType(NSString *typeString)
     [self saveEvents];
 }
 - (void)remove:sender
-{   int			folderIx = [eventBrowser selectedRowInColumn:0];
-    int			eventIx  = [eventBrowser selectedRowInColumn:1], i;
-    NSMutableArray	*events;
-    NSDictionary	*event;
+{   int             folderIx = [eventBrowser selectedRowInColumn:0];
+    int             eventIx  = [eventBrowser selectedRowInColumn:1], i;
+    NSMutableArray  *events;
+    NSDictionary    *event;
 
     if (eventIx < 0)
         return;
     events = [eventDict objectForKey:[folders objectAtIndex:folderIx]];
+    if (!events)
+        return;
     event = [events objectAtIndex:eventIx];
     if (! NSRunAlertPanel(@"", REALLYDELETEEVENT_STRING, DELETE_STRING, CANCEL_STRING, nil,
                                [event objectForKey:@"name"]) == NSAlertDefaultReturn)
@@ -436,7 +443,7 @@ static int indexFromType(NSString *typeString)
 
     [eventField setStringValue:@""];
     [timeField setStringValue:@"00:00"];
-    [tzField setStringValue:@"UTC"];
+    [tzField setStringValue:@"+0000"];
     [countryField setStringValue:@""];
     [cityField setStringValue:@""];
     [latField setStringValue:@""];
@@ -558,10 +565,10 @@ static int indexFromType(NSString *typeString)
  * modified: 2005-07-25
  */
 - (void)set:sender
-{   int			folderIx = [eventBrowser selectedRowInColumn:0];
-    int			eventIx  = [eventBrowser selectedRowInColumn:1];
-    NSArray		*events;
-    NSDictionary	*event, *infoDict = nil;
+{   int             folderIx = [eventBrowser selectedRowInColumn:0];
+    int             eventIx  = [eventBrowser selectedRowInColumn:1];
+    NSArray         *events;
+    NSDictionary    *event, *infoDict = nil;
 
     if (eventIx < 0)
         return;
@@ -569,14 +576,14 @@ static int indexFromType(NSString *typeString)
     if (!events)
         events = [extEventDict objectForKey:[folders objectAtIndex:folderIx]];
     if ([events isKindOfClass:[NSDictionary class]])	// sub-folders
-    {   NSDictionary	*subEvents;
-        int		subFolderIx = eventIx;
+    {   NSDictionary    *subEvents;
+        int             subFolderIx = eventIx;
 
         eventIx = [eventBrowser selectedRowInColumn:2];
         if (eventIx < 0)
             return;
-        subEvents = [extEventDict objectForKey:[folders objectAtIndex:folderIx]];		// Met.db
-        events = [subEvents objectForKey:[[subEvents allKeys] objectAtIndex:subFolderIx]];	// List of Rain
+        subEvents = [extEventDict objectForKey:[folders objectAtIndex:folderIx]];               // Met.db
+        events    = [subEvents objectForKey:[[subEvents allKeys] objectAtIndex:subFolderIx]];   // List of Rain
     }
     event = [events objectAtIndex:eventIx];
     if ([sender isEqual:setCompositeButton])
@@ -681,6 +688,8 @@ static int indexFromType(NSString *typeString)
                 return [[(NSDictionary*)events allKeys] count];
             }
             [eventBrowser setHasHorizontalScroller:NO];
+            // FIXME: on Apple 10.4, when Scroller is removed, a white bar remains on top of the Browser,
+            //        how to remove this? Resizing the Panel corrects the problem
             return [events count];
         case 2:		// events in sub-folders
             folderIx = [sender selectedRowInColumn:0];
@@ -736,12 +745,12 @@ static int indexFromType(NSString *typeString)
 }
 
 - (void)doClick:sender
-{   int			folderIx = [eventBrowser selectedRowInColumn:0];
-    int			eventIx  = [eventBrowser selectedRowInColumn:1];
-    NSArray		*events;
-    NSDictionary	*event;
-    NSString		*string;
-    BOOL		flag = YES;
+{   int             folderIx = [eventBrowser selectedRowInColumn:0];
+    int             eventIx  = [eventBrowser selectedRowInColumn:1];
+    NSArray         *events;
+    NSDictionary    *event;
+    NSString        *string;
+    BOOL            flag = YES;
 
     if (eventIx < 0)
     {
@@ -760,8 +769,8 @@ static int indexFromType(NSString *typeString)
     if (!events)
         events = [extEventDict objectForKey:[folders objectAtIndex:folderIx]];
     if ([events isKindOfClass:[NSDictionary class]])	// sub-folders
-    {   NSDictionary	*subEvents;
-        int		subFolderIx = eventIx;
+    {   NSDictionary    *subEvents;
+        int             subFolderIx = eventIx;
 
         eventIx = [eventBrowser selectedRowInColumn:2];
         if (eventIx < 0)
