@@ -97,7 +97,7 @@ static CIAMap	*ciaMap = nil;	// one shared cia map for all views
  * x, y are the screen coordinates in point. the latitude/longitude entries are in degrees.
  *   "longitude"   = { latitude=(x,y); latitude=(x,y); ... };
  * ...
- * modified: 2006-04-05 (projection + deg0 for CIA maps too)
+ * modified: 2006-06-09 (scale added to CIA map)
  */
 - (id)initWithContentsOfDictionary:(NSDictionary*)dict
 {
@@ -122,15 +122,15 @@ static CIAMap	*ciaMap = nil;	// one shared cia map for all views
     else
     {
         name = [[dict objectForKey:@"name"] retain];
-        if ([dict objectForKey:@"x"])
-            origin = NSMakePoint([dict floatForKey:@"x"], [dict floatForKey:@"y"]);
-        if ([dict objectForKey:@"scale"])
-            scale = [dict doubleForKey:@"scale"];
         if ([dict objectForKey:@"grid"])
             freeGrid = [[dict objectForKey:@"grid"] retain];
         if ([dict objectForKey:@"bounds"])
             bounds = rectFromPropertyList([dict objectForKey:@"bounds"]);
     }
+    if ([dict objectForKey:@"x"])
+        origin = NSMakePoint([dict floatForKey:@"x"], [dict floatForKey:@"y"]);
+    if ([dict objectForKey:@"scale"])	// if scale, no calculation is done
+        scale = [dict doubleForKey:@"scale"];
     projectionType = [[dict stringForKey:@"projection"] characterAtIndex:0];
     if ([dict objectForKey:@"deg0"])
         deg0 = [dict floatForKey:@"deg0"];
@@ -1240,22 +1240,24 @@ NSLog(@"createMap: scale = %f", scale);
 
 
 /* load map image and add background to map
- * modified: 2006-04-03
+ * modified: 2007-09-03
  */
 - (void)displayMapAtDate:(NSCalendarDate*)newMapDate inView:(DocView*)view
-{   NSString	*fileName = nil;
-    NSString	*path = [mapDict objectForKey:@"path"];
-    int		layerBG  = ([mapDict objectForKey:@"bgImageLayer"]) ? [mapDict intForKey:@"bgImageLayer"] : 0;
-    int		layerMap = ([mapDict objectForKey:@"mapLayer"])     ? [mapDict intForKey:@"mapLayer"]     : 1;
-    NSArray	*reps;
-    VImage	*image;
-    LayerObject	*layer = [[view layerList] objectAtIndex:layerMap];
-    NSArray	*mapTimes = [mapDict objectForKey:@"mapTimes"];
-    NSArray	*mapPress = [mapDict objectForKey:@"pressure"];
+{   NSString    *fileName = nil;
+    NSString    *path = [mapDict objectForKey:@"path"];
+    int         layerBG  = ([mapDict objectForKey:@"bgImageLayer"]) ? [mapDict intForKey:@"bgImageLayer"] : 0;
+    int         layerMap = ([mapDict objectForKey:@"mapLayer"])     ? [mapDict intForKey:@"mapLayer"]     : 1;
+    NSArray     *reps;
+    VImage      *image;
+    LayerObject *layer = [[view layerList] objectAtIndex:layerMap];
+    NSArray     *mapTimes = [mapDict objectForKey:@"mapTimes"];
+    NSArray     *mapPress = [mapDict objectForKey:@"pressure"];
 
     if (![mapDict objectForKey:@"fileFormat"])
         return;
 
+    [newMapDate setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
+
     /* find map closest to available maps
      */
     if ([mapTimes count])	// surface maps
@@ -1276,7 +1278,7 @@ NSLog(@"createMap: scale = %f", scale);
                                               day:[newMapDate dayOfMonth]
                                              hour:hour/100
                                            minute:hour-(hour/100*100)
-                                           second:0 timeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
+                                           second:0 timeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
         fileName = [newMapDate descriptionWithCalendarFormat:[mapDict objectForKey:@"fileFormat"]];
     }
     if ([mapPress count])	// upper air maps
@@ -1288,7 +1290,7 @@ NSLog(@"createMap: scale = %f", scale);
                                               day:[newMapDate dayOfMonth]
                                              hour:12
                                            minute:0
-                                           second:0 timeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
+                                           second:0 timeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
         /* find enabled layer/page with substring from pressure array */
         layer = nil;
         for (i=0; i<[mapPress count]; i++)
