@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  2001-09-02
- * modified: 2006-02-14 (indexOfObjectName for AC and MC added)
+ * modified: 2008-08-23 (-indexForObjectSymbol: added)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -32,6 +32,7 @@
 #include "../astroCommon.h"		// sideralTime(), ac(), mc(), sunNode()
 
 static char *ephepath = NULL;
+static NSArray *objectSymbols = nil;
 
 @interface Ephemeris(PrivateMethods)
 @end
@@ -56,7 +57,9 @@ static char *ephepath = NULL;
 - (id)init
 {
     [super init];
-    objectNames = [OBJECTS retain];
+    objectNames   = [OBJECTS retain];
+    if (!objectSymbols)
+        objectSymbols = [EPH_SYMBOLS retain];
 
     return self;
 }
@@ -89,6 +92,23 @@ static char *ephepath = NULL;
         return EPH_MC;
     return [objectNames indexOfObject:name];
 }
++ (EphemerisObjects)indexForSymbol:(NSString*)symbol
+{
+    if ([symbol isEqual:@"AC"])
+        return EPH_AC;
+    else if ([symbol isEqual:@"MC"])
+        return EPH_MC;
+    return [objectSymbols indexOfObject:symbol];
+}
++ (NSString*)symbolAtIndex:(EphemerisObjects)objIx
+{
+    switch (objIx)
+    {
+        case EPH_AC: return @"AC";
+        case EPH_MC: return @"MC";
+        default:     return [objectSymbols objectAtIndex:objIx];
+    }
+}
 
 /* get objects including AC and MC
  */
@@ -589,7 +609,7 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 }
 
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(float)lat lon:(float)lon
-{   NSCalendarDate	*st = sideralTime(utc, lon);
+{   NSCalendarDate      *st = sideralTime(utc, lon);
     NSMutableDictionary	*degreeDict = [self objectDictAtUTC:utc];
 
     [degreeDict setObject:[NSNumber numberWithDouble:ac(st, lat)] forKey:@"AC"];
@@ -599,10 +619,10 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
                                    elev:(double)alt topocentric:(BOOL)topocentric;
-{   NSMutableDictionary		*degreeDict = [NSMutableDictionary dictionary];
-    int				p;
-    EphObject			*objs;
-    //NSCalendarDate		*st = sideralTime(utc, lon);
+{   NSMutableDictionary *degreeDict = [NSMutableDictionary dictionary];
+    int                 p;
+    EphObject           *objs;
+    //NSCalendarDate    *st = sideralTime(utc, lon);
 
     objs = [self objectsAtUTC:utc lat:lat lon:lon elev:alt topocentric:topocentric];
 
@@ -614,9 +634,29 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
     //[degreeDict setObject:[NSNumber numberWithDouble:ac(st, lat)] forKey:@"AC"];
     //[degreeDict setObject:[NSNumber numberWithDouble:mc(st)] forKey:@"MC"];
 
+    calcJD   = [self julianDayForDate:utc bc:NO];
+    calcLat  = lat;
+    calcLon  = lon;
+    calcElev = alt;
+    calcTopo = topocentric;
+
     return degreeDict;
 }
 
+/* is dictionary already calculated ?
+ * created: 2006-08-18
+ */
+- (BOOL)calculatedAtDate:(NSCalendarDate*)date tolerance:(int)tol
+                     lat:(float)lat lon:(float)lon elev:(float)elev topocentric:(BOOL)topo
+{
+    if ( ( (topo || calcTopo) && calcTopo == topo
+           && Diff(elev, calcElev) < TOLERANCE
+           && Diff(lat, calcLat) < TOLERANCE && Diff(lon, calcLon) < TOLERANCE )
+         && Diff([self julianDayForDate:date bc:NO], calcJD) <= (double)tol/(24.0*60.0) )
+        return YES;
+    return NO;
+}
+
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc
 {   NSMutableDictionary		*degreeDict = [NSMutableDictionary dictionary];
     int				p;
@@ -625,6 +665,12 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [degreeDict setObject:[NSNumber numberWithDouble:objs[p].lon]
                        forKey:[objectNames objectAtIndex:p]];
+
+    calcJD   = [self julianDayForDate:utc bc:NO];
+    calcLat  = calcLon = 0.0;
+    calcElev = 0.0;
+    calcTopo = NO;
+
     return degreeDict;
 }
 
