@@ -1,11 +1,11 @@
 /* astroCommon.h
  * Common astronomical functions
  *
- * Copyright (C) 1998-2006 by vhf interservice GmbH
+ * Copyright (C) 1998-2009 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
- * modified: 2006-02-02
+ * modified: 2009-04-08
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -59,6 +59,8 @@ double vhfSideralTimeMJD(double mjd, float lon);
 
 /* Julian Day (reference = -4712, compatible to swiss ephemeris) */
 double vhfJulianDay(NSCalendarDate *date);
+double vhfJulianDayFromInt(int yyyymmdd, int hhmm);
+int vhfIntDateFromJulianDay(double jd, int *yymmdd, int *hhmm);
 double vhfSideralTime(double jd, float lon);	// sideral time in hours
 
 /* calculate astronomical values with sideral time [hours] (or better seconds and integer ???) */
@@ -71,7 +73,7 @@ float vhfLonForSideralTime(double st, NSCalendarDate *gmt);
 float vhfLonForMC(float mcDeg, NSCalendarDate *utc);
 float vhfLatForAC(float acDeg, double st);
 
-/* calculate astronomical values using NSCalendarDate (DEPRECATED !) */
+/* calculate astronomical values using NSCalendarDate (DEPRECATED ! too slow and no BC) */
 NSCalendarDate *sideralTime(NSCalendarDate *gmt, float longitude);
 float mc(NSCalendarDate *sideralTime);
 float ac(NSCalendarDate *sideralTime, float latitude);
@@ -87,8 +89,9 @@ NSString *nodeSymbol(NSString *planet);
 NSString *zodiacSign(int sign);
 NSString *aspectSymbol(float deg, float orb);
 
-/* modulus */
-double mod360(double deg);			// modulus 360 degree
+/* modulo */
+//double modulo(double num, double denom);    // dodulo
+double mod360(double deg);                  // modulo 360 degree
 
 /* aspects */
 double standardAngle( double angle );		// modulus 360 degree
